clear
set more off

import delimited "shares.dat"
ren v1 acid
ren v2 partyid
ren v3 year
ren v4 shares
ren v5 sch_all2
ren v6 literate2
ren v7 work_rural2
rename v# shi#, renumber
forvalues i=1/1000 {
replace shi`i'=round(shi`i',0.00000001)
}
save temp.dta, replace

import delimited "sharesc.dat", clear
ren v1 acid
ren v2 partyid
ren v3 year
ren v4 sharesc
rename v# shic#, renumber
forvalues i=1/1000 {
replace shic`i'=round(shic`i',0.00000001)
}

merge 1:1 acid partyid year using temp.dta
drop _merge

merge 1:1 acid partyid year using "formatlab.dta"
drop _merge
merge m:1 partyid using "partyid_short.dta"
drop if _merge==2
drop _merge
keep if year==1 & state1==0
drop year
save temp.dta, replace

*to compute individual change in turnout
collapse (sum) shi1-shi1000 shic1-shic1000, by(acid)
forvalues i=1/1000 {
replace shi`i'=shi`i'-shic`i'
ren shi`i' dshi`i'
drop shic`i'
}
reshape long dshi, i(acid) j(indno)
label var indno "simulated individual no"
ren dshi dturnout
label var dturnout "change in turnout probability"
save temp1, replace

*to compute individual change in non-major party vote
use temp, clear
keep if partyabbre!="INC" & partyabbre!="BJP" & partyabbre!="NOTA"
collapse (sum) shi1-shi1000 shic1-shic1000, by(acid)
forvalues i=1/1000 {
replace shi`i'=shi`i'-shic`i'
ren shi`i' dshi`i'
drop shic`i'
}
reshape long dshi, i(acid) j(indno)
label var indno "simulated individual no"
ren dshi dnonmajor
label var dnonmajor "change in nonmajor-party vote probability"
merge 1:1 acid indno using temp1
drop _merge
save temp1, replace

*to compute individual change in major party vote
use temp, clear
keep if partyabbre=="INC" | partyabbre=="BJP"
collapse (sum) shi1-shi1000 shic1-shic1000, by(acid)
forvalues i=1/1000 {
replace shi`i'=shi`i'-shic`i'
ren shi`i' dshi`i'
drop shic`i'
}
reshape long dshi, i(acid) j(indno)
label var indno "simulated individual no"
ren dshi dmajor
label var dmajor "change in major-party vote probability"
merge 1:1 acid indno using temp1
drop _merge
save temp1, replace

*to compute individual prob of turnout
use temp, clear
collapse (sum) shi1-shi1000, by(acid)
reshape long shi, i(acid) j(indno)
label var indno "simulated individual no"
ren shi turnout
label var turnout "individual prob of turnout"
merge 1:1 acid indno using temp1
drop _merge
save temp1, replace

*to keep individual prob of NOTA vote
use temp, clear
keep if partyid==18
keep shi1-shi1000 acid
reshape long shi, i(acid) j(indno)
label var indno "simulated individual no"
ren shi nota
label var nota "individual prob of nota vote"
merge 1:1 acid indno using temp1
drop _merge
save temp1, replace

*add voter demographics
import delimited "dfull_rearranged.dat", clear
ren v1 acid
ren v2 partyid
ren v3 year
rename v# v#, renumber

rename v1000 v1_1000
rename v2000 v2_1000
rename v3000 v3_1000
rename v2(###) v3_(#)
rename v1(###) v2_(#)
rename v# v1_(#)

merge 1:1 acid partyid year using "formatlab.dta"
drop _merge

keep if year==1 & state1==0
keep acid v1_* v2_* v3_*

collapse v1_1-v3_1000, by(acid)
reshape long v1_ v2_ v3_, i(acid) j(indno)

ren v1_ sc_all
ren v2_ literate
ren v3_ ruralworker

save temp2, replace

merge 1:1 acid indno using temp1
drop _merge

save individual, replace

* add constituency characteristics
use formatlab, clear
keep if year==1 & state1==0

egen t=tag(acid)
keep if t==1
keep acid actype2 actype3 totel stcode

merge 1:m acid using individual
drop _merge

gen ltotel=log(totel)
gen sc_all2=sc_all*actype2
gen sc_all3=sc_all*actype3
xtset acid
gen notaf = nota/turnout

bysort acid: egen aliterate=mean(literate)
bysort acid: egen asc_all=mean(sc_all)
bysort acid: egen arural=mean(ruralworker)
bysort acid: egen anota=mean(nota)
bysort acid: egen aturnout=mean(turnout)
gen anotaf = anota/aturnout
egen t=tag(acid)

* Table 6

reg anotaf aliterate arural asc_all actype2 actype3 ltotel i.stcode if t==1, r
reg nota actype2 actype3 literate ltotel sc_all ruralworker i.stcode, cluster(acid)
xtreg nota literate sc_all ruralworker, fe cluster(acid)
reg nota actype2 actype3 literate ltotel sc_all sc_all2 sc_all3 ruralworker i.stcode, cluster(acid)
xtreg nota literate sc_all sc_all2 sc_all3 ruralworker, fe cluster(acid)

* Table E.12

gen g1=dturnout/nota
gen g2=-dmajor/nota
gen g3=-dnonmajor/nota

reg g1 actype2 actype3 literate ltotel sc_all sc_all2 sc_all3 ruralworker i.stcode if dnonmajor!=. & nota!=0 , cluster(acid)
reg g2 actype2 actype3 literate ltotel sc_all sc_all2 sc_all3 ruralworker i.stcode if dnonmajor!=. & nota!=0, cluster(acid)
reg g3 actype2 actype3 literate ltotel sc_all sc_all2 sc_all3 ruralworker i.stcode if dnonmajor!=. & nota!=0, cluster(acid)

