
clear
set more off

import delimited "shares.dat"
ren v1 acid
ren v2 partyid
ren v3 year
ren v4 shares
ren v5 sch_all2
ren v6 literate2
ren v7 work_rural2
rename v# shi#, renumber
save temp.dta, replace

import delimited "sharesc.dat", clear
ren v1 acid
ren v2 partyid
ren v3 year
ren v4 sharesc
rename v# shic#, renumber

merge 1:1 acid partyid year using temp.dta
drop _merge

drop shic* shi*

merge 1:1 acid partyid year using "formatlab.dta"
drop _merge

label var shares "predicted shares within-sample"
label var sharesc "counterfactual shares without Nota"

gen dshare=shares-sharesc
label var dshare "change in vote share as Nota introduced"
sum dshare if year==1 & state1==0, det

keep if year==1 & state1==0

bysort mktid: egen pollpc=total(sharesc)
label var pollpc "counterfactual turnout"

bysort mktid: egen pollp=total(shares)
label var pollp "in-sample turnout"

gen dpollpc=pollp-pollpc if cands3!=1
label var dpollpc "estimated turnout effect of NOTA (actual minus counterfactual)"

egen tag=tag(mktid) if cands3!=1

merge m:1 partyid using "partyid_short.dta"
drop if _merge==2
drop _merge

**********
*ANALYSIS
**********

*Turnout
********

* Figure 3 / Figure E.1 / Table E.7

sum dpollpc if tag==1, det
histogram dpollpc if tag==1, xtitle((a) Change in turnout (share of eligible voters)) saving(dpollpc, replace)
sum dpollpc if tag==1 & dpollpc>0.005
di 425/520

gen dpollpc2=dpollpc/pollpc
label var dpollpc2 "estimated turnout effect of NOTA, (actual-counterfactual)/counterfactual"
histogram dpollpc2 if tag==1, xtitle((b) Change in turnout (share of turnout)) saving(dpollpc2, replace)

*Vote shares
************

* Figure 5 / Figure E.1 / Table E.7

sum dshare, det
histogram dshare, xtitle(Change in vote share) title("(a) All candidates") saving(dshare, replace)
sum dshare if dshare>-0.005
di 2991/3043

*largest change in a constituency
bysort mktid: egen mindshare=min(dshare)
label var mindshare "largest change in a candidate's vote share in constituency" 
sum mindshare if tag==1, det
histogram mindshare, xtitle(Change in vote share) xsc(r(-0.06)) xlab(#4) bin(12) title("(b) Largest change in constituency") saving(mindshare, replace)
graph combine dshare.gph mindshare.gph, iscale(0.9) ysize(2.3)
sum mindshare if mindshare>-0.005 & tag==1
di 444/520

*totals within constituencies

gen dvote=totel*dshare
label var dvote "change in vote count as Nota introduced (dshare*totel)"

bysort mktid: egen dshare_tot=total(dvote)
replace dshare_tot=dshare_tot/totel
label var dshare_tot "change in all candidates' vote share in constituency"

* Figure 4 / Figure E.1 / Table E.7

gen fdpollpc=dpollpc/(dpollpc-dshare_tot)
label var fdpollpc "fraction of nota vote in constituency explained by new turnout"
sum fdpollpc if tag==1, det
histogram fdpollpc if tag==1, xline(0.5) xtitle("Share of NOTA voters") saving(fdpollpc, replace)
sum fdpollpc if tag==1 & fdpollpc<0.5
di 38/520

*across entire electorate

* Table 5

egen electorate=total(totel) if tag==1
egen q=mean(electorate)
replace electorate=q
label var electorate "total number of eligible voters in data"
drop q

gen ger=dpollpc*totel
egen zz=total(ger) if tag==1
gen dpollpc_e=zz/electorate*100
label var dpollpc_e "change in fraction of electorate turning out (percentage points)"
sum dpollpc_e
drop zz ger
egen xx=total(dvote) if cands3!=1
gen dshare_e=xx/electorate*100
label var dshare_e "change in fraction of all candidate votes in electorate (ppoints)"
sum dshare_e
drop xx

bysort partyid: egen dshareparty_e=total(dvote)
replace dshareparty_e=dshareparty_e/electorate*100
label var dshareparty_e "change in share of electorate choosing each party (percentage points)"

gen ger2=shares*totel
egen yy=total(ger2) if cands3==1
gen notashare_e=yy/electorate
label var notashare_e "nota votes as a fraction of electorate"
sum notashare_e // this is dshare_e+dpollpc_e

bysort partyid: egen shareparty_e=total(ger2)
replace shareparty_e=shareparty_e/electorate*100
label var shareparty_e "share of electorate choosing each party (%)"
drop ger2 yy

gen ger3=pollp*totel
egen q=total(ger3) if tag==1
gen pollp_e=q/electorate*100
label var pollp_e "turnout as share of electorate"
gen abst_e=100-pollp_e
label var abst_e "abstention as share of electorate"
drop ger3 q

table partyabbre if cands3==0, c(n dshare mean shareparty_e mean dshareparty_e) // format(%9.2f)
sum dpollpc_e // change in abstention
sum abst_e // abstention

*Elections overturned
*********************

gsort mktid -shares
by mktid: gen order=_n
label var order "order of candidates in data"
gen winner=1 if order==1
label var winner "1 if winner"

gsort mktid -sharesc
by mktid: gen orderc=_n
label var orderc "order of candidates in counterfactual"
gen winnerc=1 if orderc==1
label var winnerc "1 if winnerc"
list mktid if (order==1 & orderc!=1) // 2 election results changed

table partyabbre if cands3==0, c(n dshare mean shareparty_e mean dshareparty_e count winner count winnerc)

