
use "blp.dta",clear

*COMBINE INDEPENDENTS, SMALL PARTIES
************************************

* choose cutoff for small parties (0.333, 0.25 or 0.5) by commenting out the other 2

gen party0=party
replace party0=999 if partyac1/acnumber<0.333 & cands3!=1
unique party0
unique party0 st_name ac_no year // 23 parties (incl nota), 9831 options
*/

/*
gen party0=party
replace party0=999 if partyac1/acnumber<0.25 & cands3!=1
unique party0
unique party0 st_name ac_no year // 28 parties+nota, 10359 options
*/
/*
gen party0=party
replace party0=999 if partyac1/acnumber<0.5 & cands3!=1
unique party0
unique party0 st_name ac_no year // 20 parties+nota, 9342 options
*/

replace party=party0
drop party0
unique party
table party

*summary statistics before aggregation (part of Table D.1)

gen indep1=1 if party==79
gen small1=1 if party==999
bysort st_code ac_no year: egen indep1_num=count(indep1)
bysort st_code ac_no year: egen small1_num=count(small1)
tabstat vshares2 if indep1==1, statistics(n mean sd p10 p90) c(s)
tabstat vshares2 if small1==1, statistics(n mean sd p10 p90) c(s)

*/

egen acid=group(st_code ac_no)

egen partyid=group(party)

* combine candidate characteristics for small parties and independents

foreach va in cands2 cands3 candc2 candc3 cand_age ran won minorit minorit2 cand_educ cand_crime cand_crime_serious cand_miss advert cand_assets cand_miss2 {
bysort acid year: egen k=mean(`va') if party==79
bysort acid year: egen k2=mean(`va') if party==999
replace `va'=k if party==79
replace `va'=k2 if party==999
drop k k2
}

bysort acid year: egen k=total(vsharesall) if party==79
bysort acid year: egen k2=total(vsharesall) if party==999
replace vsharesall=k if party==79
replace vsharesall=k2 if party==999
replace vshares2=vsharesall/pollppercent if party==79 | party==99
drop k k2

egen t=tag(acid year party) // keep one party per ac
keep if t==1

egen partyac = sum(t), by (year party stcode)
drop t
label var partyac "number of ac's with party's candidate in given state/year (after aggregating)"
sum partyac, det

egen t=tag(acid year party)
replace t=0 if actype2==0
egen partyac_sc = sum(t), by(year party stcode)
drop t
egen t=tag(acid year party)
replace t=0 if actype3==0
egen partyac_st = sum(t), by (year party stcode)
drop t

bysort year stcode: egen sumcandnumber=total(1-cands3)
label var sumcandnumber "total number of candidates in state (after aggregation)"
ren candnumber candnumber1
label var candnumber1 "number of candidates in ac (before aggregation)"
bysort acid year: egen candnumber=total(1-cands3)
label var candnumber "number of candidates in ac (after aggregation)"

* summary statistics after aggregation

egen tag=tag(acid year)
replace totel=totel/1000
gen reserved=0
replace reserved=1 if actype!=1

* Table B.1, panel B

tabstat totel pollppercent notashare notashareall reserved rainfall_day sch_all literate work_rural if tag==1, statistics(n mean sd p10 p90) c(s)

* Table D.1

tabstat candnumber1 indep1_num small1_num if tag==1, statistics(n mean sd p10 p90) c(s)
tabstat candnumber if tag==1, statistics(n mean sd p10 p90) c(s)
tabstat vshares2 if party==79, statistics(n mean sd p10 p90) c(s)
tabstat vshares2 if party==999, statistics(n mean sd p10 p90) c(s)

* Table B.1, panel A

gen inc=0
replace inc=1 if partyabbre=="INC"
gen bjp=0
replace bjp=1 if partyabbre=="BJP"
gen indep=0
replace indep=1 if party==79
gen small=0
replace small=1 if party==999
gen educ=cand_educ
replace educ=. if cand_miss==1
gen crim=cand_crime
replace crim=. if cand_miss==1
gen ass=cand_assets
replace ass=. if cand_miss2==1

tabstat cands2 cand_age minorit2 randist wondist educ crim ass cands3 advert inc bjp indep small, statistics(n mean sd p10 p90) c(s) // this includes NOTA "candidates"
tabstat cands2 cand_age minorit2 randist wondist educ crim ass cands3 advert inc bjp indep small, statistics(n mean sd p10 p90) c(s) // this does not


*INSTRUMENTS
************

sort year party stcode 

foreach v in cands2 cand_age minorit2 {
	bysort year stcode ac_no: egen m2`v'=mean(`v') if cands3!=1 // AC/YEAR AVERAGE characteristic. Missing for NOTA.
	bysort year stcode: egen m3`v'=mean(`v') if cands3!=1 // STATE/YEAR AVERAGE. Missing for NOTA.
	gen i3`v'=(m3`v'*sumcandnumber-m2`v'*candnumber)/(sumcandnumber-candnumber) // average without the given ac
	replace i3`v'=0 if i3`v'<0.000001
	label var i3`v' "average `v' for other ac's in state"
	bysort year party stcode: egen m`v'=mean(`v') if cands3!=1 // PARTY/STATE/YEAR AVERAGE.
	bysort year party stcode: egen t3=count(`v') // number of candidates for state/year/party
	bysort year party stcode ac_no: egen t=mean(`v') // average characteristic in ac/year/party
	bysort year party stcode ac_no: egen t2=count(`v') // number of candidates for ac/year/party
	gen i`v'=(m`v'*t3-t*t2)/(t3-t2) // average without the candidate(s) in the given ac
	drop t t2 t3
	label var i`v' "average `v' for party in other ac's in state in given year"
}

foreach v in cands2 cand_age minorit2 {
	gen i3`v'_1=i3`v' if year==2008
	gen i3`v'_2=i3`v' if year==2013
	bysort stcode ac_no: egen x=max(i3`v'_1)
	bysort stcode ac_no: egen y=max(i3`v'_2)
	replace i3`v'_1=x if i3`v'_1==.
	replace i3`v'_2=y if i3`v'_2==.
	drop x y 
	*nota
	replace i3`v'_1=0 if cands3==1
	replace i3`v'_2=0 if cands3==1
	replace i`v'=0 if cands3==1
	replace i3`v'=0 if cands3==1
	drop m`v'* m2`v'*
}

tab stcode, gen(state)

*interacting instruments with states
foreach var in icands2 icand_age iminorit2 {
	forvalues i=2/5 {
	gen `var'_s`i'=`var'*state`i'
	}
}

recode year (2008=0) (2013=1)

* Table D.5

tabstat i3cands2_1 i3cands2_2 i3cand_age_1 i3cand_age_2 i3minorit2_1 i3minorit2_2 if cands3!=1, statistics(n mean sd p10 p90) c(s)
tabstat sch_all literate work_rural if cands3==1, statistics(n mean sd p10 p90) c(s)
tabstat icands2 icand_age iminorit2 if state1==1 & cands3!=1, statistics(n mean sd p10 p90) c(s)
tabstat icands2 icand_age iminorit2 if state2==1 & cands3!=1, statistics(n mean sd p10 p90) c(s)
tabstat icands2 icand_age iminorit2 if state3==1 & cands3!=1, statistics(n mean sd p10 p90) c(s)
tabstat icands2 icand_age iminorit2 if state4==1 & cands3!=1, statistics(n mean sd p10 p90) c(s)
tabstat icands2 icand_age iminorit2 if state5==1 & cands3!=1, statistics(n mean sd p10 p90) c(s)

* if using 1st or 2nd instrument set:
global instruments="icands2 icand_age icands2_s2 icands2_s3 icands2_s4 icands2_s5 icand_age_s2 icand_age_s3 icand_age_s4 icand_age_s5 i3cands2_1 i3cands2_2 i3cand_age_1 i3cand_age_2"

/* if using 3rd instrument set:
global instruments="icands2 icand_age iminorit2 icands2_s2 icands2_s3 icands2_s4 icands2_s5 icand_age_s2 icand_age_s3 icand_age_s4 icand_age_s5 iminorit2_s2 iminorit2_s4 iminorit2_s5 i3cands2_1 i3cands2_2 i3cand_age_1 i3cand_age_2 i3minorit2_1 i3minorit2_2"
*/

/* if dropping Mizoram:
global instruments="icands2 icand_age icands2_s2 icands2_s4 icands2_s5 icand_age_s2 icand_age_s4 icand_age_s5 i3cands2_1 i3cands2_2 i3cand_age_1 i3cand_age_2"
*/


* SET UP VARIABLES AND FILES FOR MATLAB
***************************************

global controls ="actype2 actype3 rainfall_day advert"

global demogr="sch_all literate work_rural"

* choose candidate characteristics to use:
global characteristics="cands2 cand_age minorit2 randist wondist cands3" // MAIN
*global characteristics="cands2 cand_age minorit2 randist wondist cand_educ cand_crime cand_miss cands3" // with educ and crime
*global characteristics="cands2 cand_age minorit2 randist wondist cand_educ cand_crime cand_miss cand_assets cand_miss2 cands3" // with educ, crime, assets
*global characteristics="cands2 cand_age minorit2 randist wondist cand_educ cand_crime cand_crime_serious cand_miss cands3" // with educ and crime (incl. serious)
*global characteristics="cands2 cand_age minorit2 randist wondist cand_educ cand_crime cand_crime_serious cand_miss cand_assets cand_miss2 cands3" // with educ, crime (incl. serious), assets

keep acid year partyid partyabbre stcode state* party $characteristics $demogr totel pollppercent vsharesall $instruments $controls candnumber1

gen lnshare=ln(vsharesall)-ln(1-pollppercent)
label var lnshare "observed ln(s_j)-ln(s_0)"

* party dummies

sort cands3
tab partyid, gen(party)
sum party* if cands3==1

* depending on aggregation threshold used for small parties, comment out 2 other sections below:

*if 0.33 cutoff for aggregation
drop party18 // nota
label var partyid "11 is independent, 23 is small parties"
replace partyabbre="Small" if partyid==23
*/

/*
*if 0.25 cutoff for aggregation
drop party22 // nota
label var partyid "13 is independent, 28 is small parties"
replace partyabbre="Small" if partyid==28
*/

/*
*if 0.5 cutoff for aggregation
drop party15 // nota
label var partyid "9 is independent, 20 is small parties"
replace partyabbre="Small" if partyid==20
*/

/*
* If dropping Mizoram
drop if state3==1
drop state3
drop party17 party22
* need to drop corresponding observations of individual draws in demographics.dta!
*/

egen mktid=group(acid year)

sort mktid
local g=_N
egen g2=seq(), to(`g')
by mktid: gen x=g2 if _n==_N
by mktid: egen candnumber2_cum=max(x)
label var candnumber2_cum "cumulative number of candidates by ac"
drop party x g2

order acid partyid partyabbre year stcode vsharesall lnshare $characteristics $demogr ///
 $instruments mktid candnumber2_cum pollppercent $controls totel candnumber1

sort mktid partyid

preserve
keep acid year stcode party*
saveold "partyid.dta", replace
restore

drop partyabbre
 
preserve
egen z=tag(acid year)
keep if z==1
drop z

saveold "formatlab2.dta", replace
export delimited using "formatlab2.csv", novar replace
drop if _n>=1
export delimited using "varnames.csv", delim(tab) replace
restore
 
saveold "formatlab.dta", replace
export delimited using "formatlab.csv", novar replace

drop partyid state1

keep party* state* $controls

saveold "formatlab dummies.dta", replace
export delimited using "formatlab dummies.csv", novar replace
