function f = jacob(mval,theta2,vfull,dfull)
% This function computes the Jacobian of the implicit function that defines
% the mean utility as a function of theta2 (of eqn A-2 in Nevo's NittyGritty. See p6)

global ns theti thetj cdid cdindex x2

theta2w = full(sparse(theti,thetj,theta2));

expmu = exp(mufunc(x2,theta2w));
shares = ind_sh(mval,expmu); %ncand*ns matrix
clear expmu

[~,K] = size(x2); % number of characteristics
J = size(theta2w,2) - 1; % number of demographics (the -1 is for sigma)
f1 = zeros(size(cdid,1),K*(J + 1)); %first K elements will be for sigmas, next K for pi of first demographic, etc.

% computing (partial share)/(partial sigma)
for i = 1:K
	xv = (x2(:,i)*ones(1,ns)).*vfull(:,ns*(i-1)+1:ns*i); % ncand*ns matrix of xv for given k.
	
    sum1=ones(size(cdindex,1),ns); % nmarket*ns
    for g=1:ns
    sum1(:,g)=accumarray(cdid,xv(:,g).*shares(:,g)); % nmarket*ns matrix.
    end
    %note accumarray() instead of cumsum() and diff() to avoid potential scaling problem (see ind_sh.m)
  
    f1(:,i) = mean((shares.*(xv-sum1(cdid,:))),2); %average across simulations
	clear xv sum1 %temp
end


% If no demogr comment out the next para
% computing (partial share)/(partial pi)
for j = 1:J
 d = dfull(:,j:J:J*ns);
	temp1 = zeros(size(cdid,1),K);
	for i = 1:K
		xd=(x2(:,i)*ones(1,ns)).*d;    
		
        sum1=ones(size(cdindex,1),ns);
        for g=1:ns
        sum1(:,g)=accumarray(cdid,xd(:,g).*shares(:,g));
        end
    	
        temp1(:,i) = mean((shares.*(xd-sum1(cdid,:))),2)';
		clear xd sum1
	end
	f1(:,K*j+1:K*(j+1)) = temp1;
	clear temp1
end

rel = theti + (thetj - 1) * max(theti) ; % indices of relevant columns of f1 (where parameters are non-zero)

% computing (partial delta)/(partial theta2)
f = zeros(size(cdid,1),size(rel,1));
n = 1; % this will always be the first product on each market
for i = 1:size(cdindex,1) % loop through the markets
	temp = shares(n:cdindex(i),:); % take out shares on the relevant market
	H1 = temp*temp'; % sum(s_jti*s_mti) in (partial s) / (partial delta)
	H = (diag(sum(temp')) - H1)/ns; % (partial s) / (partial delta)
	f(n:cdindex(i),:) = - inv(H)*f1(n:cdindex(i),rel);
	n = cdindex(i) + 1;
end
